# Condolence Models

## Intro
`condolence-models` is a package used to detect condolence and distress
expressions, as well as empathetic comments. It is released with the
EMNLP 2020 paper `Condolence and Empathy in Online Commmunities`. 


## Install 

### Use pip
If `pip` is installed, question-intimacy could be installed directly from it:

    pip3 install condolence-models

### Dependencies
    python>=3.6.0
    torch>=1.6.0
    pytorch-transformers
    markdown
    beautifulsoup4
    numpy
    tqdm
    simpletransformers
    pandas
    numpy
    
## Usage and Example

## Contact
Naitian Zhou (naitian@umich.edu)
